# coding: utf-8

# flake8: noqa

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.1.4039"

# Define package exports
__all__ = [
    "AmazonEcrKeyIntegrationApi",
    "AmazonEcrRoleIntegrationApi",
    "BrokersApi",
    "CloudInstancesApi",
    "CollaboratorsApi",
    "ComplianceApi",
    "ContainerImagesApi",
    "CustomFieldsApi",
    "IntegrationsApi",
    "IssuesApi",
    "IssuesV2Api",
    "PoliciesApi",
    "ProductUnitsApi",
    "RepositoriesApi",
    "RepositoryGroupsApi",
    "SDLCAssetsApi",
    "SavedQueriesApi",
    "TagsApi",
    "WorkspacesApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AddIssueCommentDto",
    "AiValidationResult",
    "AmazonEcrKeyIntegrationCreateDto",
    "AmazonEcrKeyIntegrationEditDto",
    "AmazonEcrRoleIntegrationCreateDto",
    "AmazonEcrRoleIntegrationEditDto",
    "ApplyBulkWorkspaceOperationDto",
    "ApplyBulkWorkspaceRolesOperationDto",
    "AssetConnectionDto",
    "AutomaticCheckDto",
    "AwsRegion",
    "AzureContainerRegistryIntegrationCreateDto",
    "AzureContainerRegistryIntegrationEditDto",
    "BasicIssue",
    "BrokerConnectionStatus",
    "BrokerDto",
    "BrokerStatus",
    "BusinessImpact",
    "Category",
    "ClosingReason",
    "CloudInstanceDto",
    "CloudInstancesToContainersOperationDto",
    "CollaboratorDto",
    "CollaboratorRepositoryPermission",
    "ComplianceCriteriaDto",
    "ComplianceDto",
    "ComplianceReportDto",
    "ComplianceReportIntegrationDto",
    "ComplianceReportRequestDto",
    "ComplianceReportRequirementDto",
    "ComplianceReportWorkspaceDto",
    "ComplianceRequirementDto",
    "ComplianceWithCriteriasDto",
    "ContainerImageDto",
    "ContainerImageVersionDto",
    "ContainerToCloudResourceOperationDto",
    "ContainerToRepositoryOperationDto",
    "ControlClassification",
    "ControlSourceType",
    "ControlType",
    "CorrelatedCloudInstance",
    "CorrelatedRepositoryDto",
    "CreateAutomaticCheckDto",
    "CreateIssuesTagDto",
    "CreateProductUnitBadRequestDto",
    "CreateProductUnitDto",
    "CreateTagDto",
    "CreateWorkspaceDto",
    "CreateWorkspaceGroupDto",
    "CustomFieldBoolTypeDto",
    "CustomFieldDateTypeDto",
    "CustomFieldDto",
    "CustomFieldDtoType",
    "CustomFieldEntity",
    "CustomFieldFileTypeDto",
    "CustomFieldIdentityTypeDto",
    "CustomFieldNumberTypeDto",
    "CustomFieldTextTypeDto",
    "CustomFieldType",
    "CustomerFacingIssueDto",
    "CustomerFacingIssueSourceDto",
    "CustomerFacingIssuesPageDto",
    "DastConfidenceLevel",
    "DependencyFixType",
    "DetailedSdlcAssetInformationDto",
    "DiscoveredSdlcAssetDto",
    "DiscoveryConnectionEvidenceType",
    "FrameworkPolicyType",
    "GetCustomFieldsResponseDto",
    "GetSdlcAssetGraphEvidenceByIdsResponseDto",
    "GoogleContainerRegistryIntegrationCreateDto",
    "GoogleContainerRegistryIntegrationEditDto",
    "IntegrationBadResponseDto",
    "IntegrationDto",
    "IntegrationError",
    "IntegrationFailingReason",
    "IntegrationManagementDto",
    "IntegrationStatus",
    "IntegrationType",
    "IssueAssignment",
    "IssueClosingLocationDto",
    "IssueCommentDto",
    "IssueCountBySeverityDto",
    "IssueDto",
    "IssueIgnoringReasonDto",
    "IssueOpeningReasonDto",
    "IssueOriginDto",
    "IssueOriginParams",
    "IssueSortingColumn",
    "IssueStatus",
    "IssueTagDto",
    "IssueTicketingDto",
    "IssueType",
    "IssuesTagDto",
    "JenkinsIntegrationCreateDto",
    "JenkinsIntegrationEditDto",
    "LegitScoreCategoryDto",
    "LegitScoreDto",
    "LegitScoreGrade",
    "LegitScoreRequirementDto",
    "LegitScoreRequirementGroupType",
    "LegitScoreRequirementType",
    "ListSortDirection",
    "ManualCheckDto",
    "OriginType",
    "PatchLegitIssueAssigneeDto",
    "PatchLegitIssueStatusDto",
    "PatchLegitIssueUnifiedStatusDto",
    "PatchLegitIssuesStatusDto",
    "PatchProductUnitCustomFieldByName",
    "PatchProductUnitCustomFieldDto",
    "PatchProductUnitCustomFieldsByNameDto",
    "PatchProductUnitCustomFieldsDto",
    "PatchProductUnitDto",
    "PatchSecurityChampionIdDto",
    "PermissionMetaType",
    "PolicyDto",
    "ProblemDetails",
    "ProductConnectionType",
    "ProductTreeNodeDto",
    "ProductUnitAssetDto",
    "ProductUnitDto",
    "ProductUnitDtoCustomFieldsValue",
    "ProductUnitEnvironment",
    "ProductUnitNameDto",
    "ProductUnitType",
    "RepositoriesToContainersOperationDto",
    "RepositoryControlDto",
    "RepositoryDirectory",
    "RepositoryDto",
    "RepositoryGroupDto",
    "RepositoryVisibility",
    "ScmType",
    "SdlcAssetDto",
    "SdlcAssetGraphAssetDto",
    "SdlcAssetGraphDto",
    "SdlcAssetGraphEvidenceDto",
    "SdlcAssetGraphLinkDto",
    "SdlcAssetGraphLinkDtoEvidences",
    "SdlcAssetMetaType",
    "SdlcAssetType",
    "SecretIssueValidityStatus",
    "Severity",
    "SnoozedType",
    "TagDto",
    "TagSource",
    "UserDto",
    "UserPermission",
    "UserRole",
    "WorkspaceCreatedDto",
    "WorkspaceDto",
    "WorkspaceGroupDto",
    "WorkspaceGroupTreeNodeDto",
    "WorkspaceHierarchyDto",
    "WorkspaceTreeNodeDto",
    "WorkspaceType",
]

# import apis into sdk package
from legit_api_client.api.amazon_ecr_key_integration_api import AmazonEcrKeyIntegrationApi as AmazonEcrKeyIntegrationApi
from legit_api_client.api.amazon_ecr_role_integration_api import AmazonEcrRoleIntegrationApi as AmazonEcrRoleIntegrationApi
from legit_api_client.api.brokers_api import BrokersApi as BrokersApi
from legit_api_client.api.cloud_instances_api import CloudInstancesApi as CloudInstancesApi
from legit_api_client.api.collaborators_api import CollaboratorsApi as CollaboratorsApi
from legit_api_client.api.compliance_api import ComplianceApi as ComplianceApi
from legit_api_client.api.container_images_api import ContainerImagesApi as ContainerImagesApi
from legit_api_client.api.custom_fields_api import CustomFieldsApi as CustomFieldsApi
from legit_api_client.api.integrations_api import IntegrationsApi as IntegrationsApi
from legit_api_client.api.issues_api import IssuesApi as IssuesApi
from legit_api_client.api.issues_v2_api import IssuesV2Api as IssuesV2Api
from legit_api_client.api.policies_api import PoliciesApi as PoliciesApi
from legit_api_client.api.product_units_api import ProductUnitsApi as ProductUnitsApi
from legit_api_client.api.repositories_api import RepositoriesApi as RepositoriesApi
from legit_api_client.api.repository_groups_api import RepositoryGroupsApi as RepositoryGroupsApi
from legit_api_client.api.sdlc_assets_api import SDLCAssetsApi as SDLCAssetsApi
from legit_api_client.api.saved_queries_api import SavedQueriesApi as SavedQueriesApi
from legit_api_client.api.tags_api import TagsApi as TagsApi
from legit_api_client.api.workspaces_api import WorkspacesApi as WorkspacesApi

# import ApiClient
from legit_api_client.api_response import ApiResponse as ApiResponse
from legit_api_client.api_client import ApiClient as ApiClient
from legit_api_client.configuration import Configuration as Configuration
from legit_api_client.exceptions import OpenApiException as OpenApiException
from legit_api_client.exceptions import ApiTypeError as ApiTypeError
from legit_api_client.exceptions import ApiValueError as ApiValueError
from legit_api_client.exceptions import ApiKeyError as ApiKeyError
from legit_api_client.exceptions import ApiAttributeError as ApiAttributeError
from legit_api_client.exceptions import ApiException as ApiException

# import models into sdk package
from legit_api_client.models.add_issue_comment_dto import AddIssueCommentDto as AddIssueCommentDto
from legit_api_client.models.ai_validation_result import AiValidationResult as AiValidationResult
from legit_api_client.models.amazon_ecr_key_integration_create_dto import AmazonEcrKeyIntegrationCreateDto as AmazonEcrKeyIntegrationCreateDto
from legit_api_client.models.amazon_ecr_key_integration_edit_dto import AmazonEcrKeyIntegrationEditDto as AmazonEcrKeyIntegrationEditDto
from legit_api_client.models.amazon_ecr_role_integration_create_dto import AmazonEcrRoleIntegrationCreateDto as AmazonEcrRoleIntegrationCreateDto
from legit_api_client.models.amazon_ecr_role_integration_edit_dto import AmazonEcrRoleIntegrationEditDto as AmazonEcrRoleIntegrationEditDto
from legit_api_client.models.apply_bulk_workspace_operation_dto import ApplyBulkWorkspaceOperationDto as ApplyBulkWorkspaceOperationDto
from legit_api_client.models.apply_bulk_workspace_roles_operation_dto import ApplyBulkWorkspaceRolesOperationDto as ApplyBulkWorkspaceRolesOperationDto
from legit_api_client.models.asset_connection_dto import AssetConnectionDto as AssetConnectionDto
from legit_api_client.models.automatic_check_dto import AutomaticCheckDto as AutomaticCheckDto
from legit_api_client.models.aws_region import AwsRegion as AwsRegion
from legit_api_client.models.azure_container_registry_integration_create_dto import AzureContainerRegistryIntegrationCreateDto as AzureContainerRegistryIntegrationCreateDto
from legit_api_client.models.azure_container_registry_integration_edit_dto import AzureContainerRegistryIntegrationEditDto as AzureContainerRegistryIntegrationEditDto
from legit_api_client.models.basic_issue import BasicIssue as BasicIssue
from legit_api_client.models.broker_connection_status import BrokerConnectionStatus as BrokerConnectionStatus
from legit_api_client.models.broker_dto import BrokerDto as BrokerDto
from legit_api_client.models.broker_status import BrokerStatus as BrokerStatus
from legit_api_client.models.business_impact import BusinessImpact as BusinessImpact
from legit_api_client.models.category import Category as Category
from legit_api_client.models.closing_reason import ClosingReason as ClosingReason
from legit_api_client.models.cloud_instance_dto import CloudInstanceDto as CloudInstanceDto
from legit_api_client.models.cloud_instances_to_containers_operation_dto import CloudInstancesToContainersOperationDto as CloudInstancesToContainersOperationDto
from legit_api_client.models.collaborator_dto import CollaboratorDto as CollaboratorDto
from legit_api_client.models.collaborator_repository_permission import CollaboratorRepositoryPermission as CollaboratorRepositoryPermission
from legit_api_client.models.compliance_criteria_dto import ComplianceCriteriaDto as ComplianceCriteriaDto
from legit_api_client.models.compliance_dto import ComplianceDto as ComplianceDto
from legit_api_client.models.compliance_report_dto import ComplianceReportDto as ComplianceReportDto
from legit_api_client.models.compliance_report_integration_dto import ComplianceReportIntegrationDto as ComplianceReportIntegrationDto
from legit_api_client.models.compliance_report_request_dto import ComplianceReportRequestDto as ComplianceReportRequestDto
from legit_api_client.models.compliance_report_requirement_dto import ComplianceReportRequirementDto as ComplianceReportRequirementDto
from legit_api_client.models.compliance_report_workspace_dto import ComplianceReportWorkspaceDto as ComplianceReportWorkspaceDto
from legit_api_client.models.compliance_requirement_dto import ComplianceRequirementDto as ComplianceRequirementDto
from legit_api_client.models.compliance_with_criterias_dto import ComplianceWithCriteriasDto as ComplianceWithCriteriasDto
from legit_api_client.models.container_image_dto import ContainerImageDto as ContainerImageDto
from legit_api_client.models.container_image_version_dto import ContainerImageVersionDto as ContainerImageVersionDto
from legit_api_client.models.container_to_cloud_resource_operation_dto import ContainerToCloudResourceOperationDto as ContainerToCloudResourceOperationDto
from legit_api_client.models.container_to_repository_operation_dto import ContainerToRepositoryOperationDto as ContainerToRepositoryOperationDto
from legit_api_client.models.control_classification import ControlClassification as ControlClassification
from legit_api_client.models.control_source_type import ControlSourceType as ControlSourceType
from legit_api_client.models.control_type import ControlType as ControlType
from legit_api_client.models.correlated_cloud_instance import CorrelatedCloudInstance as CorrelatedCloudInstance
from legit_api_client.models.correlated_repository_dto import CorrelatedRepositoryDto as CorrelatedRepositoryDto
from legit_api_client.models.create_automatic_check_dto import CreateAutomaticCheckDto as CreateAutomaticCheckDto
from legit_api_client.models.create_issues_tag_dto import CreateIssuesTagDto as CreateIssuesTagDto
from legit_api_client.models.create_product_unit_bad_request_dto import CreateProductUnitBadRequestDto as CreateProductUnitBadRequestDto
from legit_api_client.models.create_product_unit_dto import CreateProductUnitDto as CreateProductUnitDto
from legit_api_client.models.create_tag_dto import CreateTagDto as CreateTagDto
from legit_api_client.models.create_workspace_dto import CreateWorkspaceDto as CreateWorkspaceDto
from legit_api_client.models.create_workspace_group_dto import CreateWorkspaceGroupDto as CreateWorkspaceGroupDto
from legit_api_client.models.custom_field_bool_type_dto import CustomFieldBoolTypeDto as CustomFieldBoolTypeDto
from legit_api_client.models.custom_field_date_type_dto import CustomFieldDateTypeDto as CustomFieldDateTypeDto
from legit_api_client.models.custom_field_dto import CustomFieldDto as CustomFieldDto
from legit_api_client.models.custom_field_dto_type import CustomFieldDtoType as CustomFieldDtoType
from legit_api_client.models.custom_field_entity import CustomFieldEntity as CustomFieldEntity
from legit_api_client.models.custom_field_file_type_dto import CustomFieldFileTypeDto as CustomFieldFileTypeDto
from legit_api_client.models.custom_field_identity_type_dto import CustomFieldIdentityTypeDto as CustomFieldIdentityTypeDto
from legit_api_client.models.custom_field_number_type_dto import CustomFieldNumberTypeDto as CustomFieldNumberTypeDto
from legit_api_client.models.custom_field_text_type_dto import CustomFieldTextTypeDto as CustomFieldTextTypeDto
from legit_api_client.models.custom_field_type import CustomFieldType as CustomFieldType
from legit_api_client.models.customer_facing_issue_dto import CustomerFacingIssueDto as CustomerFacingIssueDto
from legit_api_client.models.customer_facing_issue_source_dto import CustomerFacingIssueSourceDto as CustomerFacingIssueSourceDto
from legit_api_client.models.customer_facing_issues_page_dto import CustomerFacingIssuesPageDto as CustomerFacingIssuesPageDto
from legit_api_client.models.dast_confidence_level import DastConfidenceLevel as DastConfidenceLevel
from legit_api_client.models.dependency_fix_type import DependencyFixType as DependencyFixType
from legit_api_client.models.detailed_sdlc_asset_information_dto import DetailedSdlcAssetInformationDto as DetailedSdlcAssetInformationDto
from legit_api_client.models.discovered_sdlc_asset_dto import DiscoveredSdlcAssetDto as DiscoveredSdlcAssetDto
from legit_api_client.models.discovery_connection_evidence_type import DiscoveryConnectionEvidenceType as DiscoveryConnectionEvidenceType
from legit_api_client.models.framework_policy_type import FrameworkPolicyType as FrameworkPolicyType
from legit_api_client.models.get_custom_fields_response_dto import GetCustomFieldsResponseDto as GetCustomFieldsResponseDto
from legit_api_client.models.get_sdlc_asset_graph_evidence_by_ids_response_dto import GetSdlcAssetGraphEvidenceByIdsResponseDto as GetSdlcAssetGraphEvidenceByIdsResponseDto
from legit_api_client.models.google_container_registry_integration_create_dto import GoogleContainerRegistryIntegrationCreateDto as GoogleContainerRegistryIntegrationCreateDto
from legit_api_client.models.google_container_registry_integration_edit_dto import GoogleContainerRegistryIntegrationEditDto as GoogleContainerRegistryIntegrationEditDto
from legit_api_client.models.integration_bad_response_dto import IntegrationBadResponseDto as IntegrationBadResponseDto
from legit_api_client.models.integration_dto import IntegrationDto as IntegrationDto
from legit_api_client.models.integration_error import IntegrationError as IntegrationError
from legit_api_client.models.integration_failing_reason import IntegrationFailingReason as IntegrationFailingReason
from legit_api_client.models.integration_management_dto import IntegrationManagementDto as IntegrationManagementDto
from legit_api_client.models.integration_status import IntegrationStatus as IntegrationStatus
from legit_api_client.models.integration_type import IntegrationType as IntegrationType
from legit_api_client.models.issue_assignment import IssueAssignment as IssueAssignment
from legit_api_client.models.issue_closing_location_dto import IssueClosingLocationDto as IssueClosingLocationDto
from legit_api_client.models.issue_comment_dto import IssueCommentDto as IssueCommentDto
from legit_api_client.models.issue_count_by_severity_dto import IssueCountBySeverityDto as IssueCountBySeverityDto
from legit_api_client.models.issue_dto import IssueDto as IssueDto
from legit_api_client.models.issue_ignoring_reason_dto import IssueIgnoringReasonDto as IssueIgnoringReasonDto
from legit_api_client.models.issue_opening_reason_dto import IssueOpeningReasonDto as IssueOpeningReasonDto
from legit_api_client.models.issue_origin_dto import IssueOriginDto as IssueOriginDto
from legit_api_client.models.issue_origin_params import IssueOriginParams as IssueOriginParams
from legit_api_client.models.issue_sorting_column import IssueSortingColumn as IssueSortingColumn
from legit_api_client.models.issue_status import IssueStatus as IssueStatus
from legit_api_client.models.issue_tag_dto import IssueTagDto as IssueTagDto
from legit_api_client.models.issue_ticketing_dto import IssueTicketingDto as IssueTicketingDto
from legit_api_client.models.issue_type import IssueType as IssueType
from legit_api_client.models.issues_tag_dto import IssuesTagDto as IssuesTagDto
from legit_api_client.models.jenkins_integration_create_dto import JenkinsIntegrationCreateDto as JenkinsIntegrationCreateDto
from legit_api_client.models.jenkins_integration_edit_dto import JenkinsIntegrationEditDto as JenkinsIntegrationEditDto
from legit_api_client.models.legit_score_category_dto import LegitScoreCategoryDto as LegitScoreCategoryDto
from legit_api_client.models.legit_score_dto import LegitScoreDto as LegitScoreDto
from legit_api_client.models.legit_score_grade import LegitScoreGrade as LegitScoreGrade
from legit_api_client.models.legit_score_requirement_dto import LegitScoreRequirementDto as LegitScoreRequirementDto
from legit_api_client.models.legit_score_requirement_group_type import LegitScoreRequirementGroupType as LegitScoreRequirementGroupType
from legit_api_client.models.legit_score_requirement_type import LegitScoreRequirementType as LegitScoreRequirementType
from legit_api_client.models.list_sort_direction import ListSortDirection as ListSortDirection
from legit_api_client.models.manual_check_dto import ManualCheckDto as ManualCheckDto
from legit_api_client.models.origin_type import OriginType as OriginType
from legit_api_client.models.patch_legit_issue_assignee_dto import PatchLegitIssueAssigneeDto as PatchLegitIssueAssigneeDto
from legit_api_client.models.patch_legit_issue_status_dto import PatchLegitIssueStatusDto as PatchLegitIssueStatusDto
from legit_api_client.models.patch_legit_issue_unified_status_dto import PatchLegitIssueUnifiedStatusDto as PatchLegitIssueUnifiedStatusDto
from legit_api_client.models.patch_legit_issues_status_dto import PatchLegitIssuesStatusDto as PatchLegitIssuesStatusDto
from legit_api_client.models.patch_product_unit_custom_field_by_name import PatchProductUnitCustomFieldByName as PatchProductUnitCustomFieldByName
from legit_api_client.models.patch_product_unit_custom_field_dto import PatchProductUnitCustomFieldDto as PatchProductUnitCustomFieldDto
from legit_api_client.models.patch_product_unit_custom_fields_by_name_dto import PatchProductUnitCustomFieldsByNameDto as PatchProductUnitCustomFieldsByNameDto
from legit_api_client.models.patch_product_unit_custom_fields_dto import PatchProductUnitCustomFieldsDto as PatchProductUnitCustomFieldsDto
from legit_api_client.models.patch_product_unit_dto import PatchProductUnitDto as PatchProductUnitDto
from legit_api_client.models.patch_security_champion_id_dto import PatchSecurityChampionIdDto as PatchSecurityChampionIdDto
from legit_api_client.models.permission_meta_type import PermissionMetaType as PermissionMetaType
from legit_api_client.models.policy_dto import PolicyDto as PolicyDto
from legit_api_client.models.problem_details import ProblemDetails as ProblemDetails
from legit_api_client.models.product_connection_type import ProductConnectionType as ProductConnectionType
from legit_api_client.models.product_tree_node_dto import ProductTreeNodeDto as ProductTreeNodeDto
from legit_api_client.models.product_unit_asset_dto import ProductUnitAssetDto as ProductUnitAssetDto
from legit_api_client.models.product_unit_dto import ProductUnitDto as ProductUnitDto
from legit_api_client.models.product_unit_dto_custom_fields_value import ProductUnitDtoCustomFieldsValue as ProductUnitDtoCustomFieldsValue
from legit_api_client.models.product_unit_environment import ProductUnitEnvironment as ProductUnitEnvironment
from legit_api_client.models.product_unit_name_dto import ProductUnitNameDto as ProductUnitNameDto
from legit_api_client.models.product_unit_type import ProductUnitType as ProductUnitType
from legit_api_client.models.repositories_to_containers_operation_dto import RepositoriesToContainersOperationDto as RepositoriesToContainersOperationDto
from legit_api_client.models.repository_control_dto import RepositoryControlDto as RepositoryControlDto
from legit_api_client.models.repository_directory import RepositoryDirectory as RepositoryDirectory
from legit_api_client.models.repository_dto import RepositoryDto as RepositoryDto
from legit_api_client.models.repository_group_dto import RepositoryGroupDto as RepositoryGroupDto
from legit_api_client.models.repository_visibility import RepositoryVisibility as RepositoryVisibility
from legit_api_client.models.scm_type import ScmType as ScmType
from legit_api_client.models.sdlc_asset_dto import SdlcAssetDto as SdlcAssetDto
from legit_api_client.models.sdlc_asset_graph_asset_dto import SdlcAssetGraphAssetDto as SdlcAssetGraphAssetDto
from legit_api_client.models.sdlc_asset_graph_dto import SdlcAssetGraphDto as SdlcAssetGraphDto
from legit_api_client.models.sdlc_asset_graph_evidence_dto import SdlcAssetGraphEvidenceDto as SdlcAssetGraphEvidenceDto
from legit_api_client.models.sdlc_asset_graph_link_dto import SdlcAssetGraphLinkDto as SdlcAssetGraphLinkDto
from legit_api_client.models.sdlc_asset_graph_link_dto_evidences import SdlcAssetGraphLinkDtoEvidences as SdlcAssetGraphLinkDtoEvidences
from legit_api_client.models.sdlc_asset_meta_type import SdlcAssetMetaType as SdlcAssetMetaType
from legit_api_client.models.sdlc_asset_type import SdlcAssetType as SdlcAssetType
from legit_api_client.models.secret_issue_validity_status import SecretIssueValidityStatus as SecretIssueValidityStatus
from legit_api_client.models.severity import Severity as Severity
from legit_api_client.models.snoozed_type import SnoozedType as SnoozedType
from legit_api_client.models.tag_dto import TagDto as TagDto
from legit_api_client.models.tag_source import TagSource as TagSource
from legit_api_client.models.user_dto import UserDto as UserDto
from legit_api_client.models.user_permission import UserPermission as UserPermission
from legit_api_client.models.user_role import UserRole as UserRole
from legit_api_client.models.workspace_created_dto import WorkspaceCreatedDto as WorkspaceCreatedDto
from legit_api_client.models.workspace_dto import WorkspaceDto as WorkspaceDto
from legit_api_client.models.workspace_group_dto import WorkspaceGroupDto as WorkspaceGroupDto
from legit_api_client.models.workspace_group_tree_node_dto import WorkspaceGroupTreeNodeDto as WorkspaceGroupTreeNodeDto
from legit_api_client.models.workspace_hierarchy_dto import WorkspaceHierarchyDto as WorkspaceHierarchyDto
from legit_api_client.models.workspace_tree_node_dto import WorkspaceTreeNodeDto as WorkspaceTreeNodeDto
from legit_api_client.models.workspace_type import WorkspaceType as WorkspaceType



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class IssueType(str, Enum):
    """
    IssueType
    """

    """
    allowed enum values
    """
    MISCONFIGURATION = 'Misconfiguration'
    SECRET = 'Secret'
    IAC = 'IaC'
    INCIDENT = 'Incident'
    CONTROLS = 'Controls'
    PIPELINE = 'Pipeline'
    DEPENDENCIES = 'Dependencies'
    SAST = 'Sast'
    VULNERABLEASSETS = 'VulnerableAssets'
    OTHER = 'Other'
    CONTAINERSCANNING = 'ContainerScanning'
    DAST = 'Dast'
    AIRISKS = 'AiRisks'
    INFRASTRUCTURE = 'Infrastructure'
    APISECURITY = 'ApiSecurity'
    PENTEST = 'Pentest'
    CLOUD = 'Cloud'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of IssueType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.patch_product_unit_dto import PatchProductUnitDto

class TestPatchProductUnitDto(unittest.TestCase):
    """PatchProductUnitDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchProductUnitDto:
        """Test PatchProductUnitDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchProductUnitDto`
        """
        model = PatchProductUnitDto()
        if include_optional:
            return PatchProductUnitDto(
                name = 'Q!&h808cmu-h<I {ljZ4 ',
                description = '',
                workspace_id = '',
                type = 'Other',
                environment = 'Development',
                business_impact = 'Low',
                attach_repository_ids = [
                    ''
                    ],
                attach_repository_group_ids = [
                    ''
                    ],
                attach_integration_ids = [
                    ''
                    ],
                attach_nested_product_unit_ids = [
                    ''
                    ],
                attach_repository_name_substrings = [
                    ''
                    ],
                attach_repository_directories = [
                    legit_api_client.models.repository_directory.RepositoryDirectory(
                        repository_id = '', 
                        directory = '', )
                    ],
                detach_repository_ids = [
                    ''
                    ],
                detach_repository_group_ids = [
                    ''
                    ],
                detach_integration_ids = [
                    ''
                    ],
                detach_nested_product_unit_ids = [
                    ''
                    ],
                detach_repository_name_substrings = [
                    ''
                    ],
                detach_repository_directories = [
                    legit_api_client.models.repository_directory.RepositoryDirectory(
                        repository_id = '', 
                        directory = '', )
                    ],
                patch_security_champion_id = legit_api_client.models.patch_security_champion_id_dto.PatchSecurityChampionIdDto(
                    security_champion_id = '', )
            )
        else:
            return PatchProductUnitDto(
        )
        """

    def testPatchProductUnitDto(self):
        """Test PatchProductUnitDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.asset_connection_dto import AssetConnectionDto

class TestAssetConnectionDto(unittest.TestCase):
    """AssetConnectionDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AssetConnectionDto:
        """Test AssetConnectionDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AssetConnectionDto`
        """
        model = AssetConnectionDto()
        if include_optional:
            return AssetConnectionDto(
                evidence_type = 'Unknown',
                first_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                detailed_sdlc_asset = legit_api_client.models.detailed_sdlc_asset_information_dto.DetailedSdlcAssetInformationDto(
                    sdlc_asset = null, 
                    name = '', 
                    issues_count = 56, 
                    setup_success_status_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    highest_severity = null, 
                    source_type = null, )
            )
        else:
            return AssetConnectionDto(
        )
        """

    def testAssetConnectionDto(self):
        """Test AssetConnectionDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from legit_api_client.models.business_impact import BusinessImpact
from legit_api_client.models.patch_security_champion_id_dto import PatchSecurityChampionIdDto
from legit_api_client.models.product_unit_environment import ProductUnitEnvironment
from legit_api_client.models.product_unit_type import ProductUnitType
from legit_api_client.models.repository_directory import RepositoryDirectory
from typing import Optional, Set
from typing_extensions import Self

class PatchProductUnitDto(BaseModel):
    """
    PatchProductUnitDto
    """ # noqa: E501
    name: Optional[Annotated[str, Field(strict=True)]] = None
    description: Optional[StrictStr] = None
    workspace_id: Optional[StrictStr] = Field(default=None, alias="workspaceId")
    type: Optional[ProductUnitType] = None
    environment: Optional[ProductUnitEnvironment] = None
    business_impact: Optional[BusinessImpact] = Field(default=None, alias="businessImpact")
    attach_repository_ids: Optional[List[StrictStr]] = Field(default=None, alias="attachRepositoryIds")
    attach_repository_group_ids: Optional[List[StrictStr]] = Field(default=None, alias="attachRepositoryGroupIds")
    attach_integration_ids: Optional[List[StrictStr]] = Field(default=None, alias="attachIntegrationIds")
    attach_nested_product_unit_ids: Optional[List[StrictStr]] = Field(default=None, alias="attachNestedProductUnitIds")
    attach_repository_name_substrings: Optional[List[StrictStr]] = Field(default=None, alias="attachRepositoryNameSubstrings")
    attach_repository_directories: Optional[List[RepositoryDirectory]] = Field(default=None, alias="attachRepositoryDirectories")
    detach_repository_ids: Optional[List[StrictStr]] = Field(default=None, alias="detachRepositoryIds")
    detach_repository_group_ids: Optional[List[StrictStr]] = Field(default=None, alias="detachRepositoryGroupIds")
    detach_integration_ids: Optional[List[StrictStr]] = Field(default=None, alias="detachIntegrationIds")
    detach_nested_product_unit_ids: Optional[List[StrictStr]] = Field(default=None, alias="detachNestedProductUnitIds")
    detach_repository_name_substrings: Optional[List[StrictStr]] = Field(default=None, alias="detachRepositoryNameSubstrings")
    detach_repository_directories: Optional[List[RepositoryDirectory]] = Field(default=None, alias="detachRepositoryDirectories")
    patch_security_champion_id: Optional[PatchSecurityChampionIdDto] = Field(default=None, alias="patchSecurityChampionId")
    __properties: ClassVar[List[str]] = ["name", "description", "workspaceId", "type", "environment", "businessImpact", "attachRepositoryIds", "attachRepositoryGroupIds", "attachIntegrationIds", "attachNestedProductUnitIds", "attachRepositoryNameSubstrings", "attachRepositoryDirectories", "detachRepositoryIds", "detachRepositoryGroupIds", "detachIntegrationIds", "detachNestedProductUnitIds", "detachRepositoryNameSubstrings", "detachRepositoryDirectories", "patchSecurityChampionId"]

    @field_validator('name')
    def name_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[\w\s!@#$%\^&*()={}:;<>+\'-\/]{1,60}$", value):
            raise ValueError(r"must validate the regular expression /^[\w\s!@#$%\^&*()={}:;<>+'-\/]{1,60}$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PatchProductUnitDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attach_repository_directories (list)
        _items = []
        if self.attach_repository_directories:
            for _item_attach_repository_directories in self.attach_repository_directories:
                if _item_attach_repository_directories:
                    _items.append(_item_attach_repository_directories.to_dict())
            _dict['attachRepositoryDirectories'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in detach_repository_directories (list)
        _items = []
        if self.detach_repository_directories:
            for _item_detach_repository_directories in self.detach_repository_directories:
                if _item_detach_repository_directories:
                    _items.append(_item_detach_repository_directories.to_dict())
            _dict['detachRepositoryDirectories'] = _items
        # override the default output from pydantic by calling `to_dict()` of patch_security_champion_id
        if self.patch_security_champion_id:
            _dict['patchSecurityChampionId'] = self.patch_security_champion_id.to_dict()
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if workspace_id (nullable) is None
        # and model_fields_set contains the field
        if self.workspace_id is None and "workspace_id" in self.model_fields_set:
            _dict['workspaceId'] = None

        # set to None if type (nullable) is None
        # and model_fields_set contains the field
        if self.type is None and "type" in self.model_fields_set:
            _dict['type'] = None

        # set to None if environment (nullable) is None
        # and model_fields_set contains the field
        if self.environment is None and "environment" in self.model_fields_set:
            _dict['environment'] = None

        # set to None if business_impact (nullable) is None
        # and model_fields_set contains the field
        if self.business_impact is None and "business_impact" in self.model_fields_set:
            _dict['businessImpact'] = None

        # set to None if attach_repository_ids (nullable) is None
        # and model_fields_set contains the field
        if self.attach_repository_ids is None and "attach_repository_ids" in self.model_fields_set:
            _dict['attachRepositoryIds'] = None

        # set to None if attach_repository_group_ids (nullable) is None
        # and model_fields_set contains the field
        if self.attach_repository_group_ids is None and "attach_repository_group_ids" in self.model_fields_set:
            _dict['attachRepositoryGroupIds'] = None

        # set to None if attach_integration_ids (nullable) is None
        # and model_fields_set contains the field
        if self.attach_integration_ids is None and "attach_integration_ids" in self.model_fields_set:
            _dict['attachIntegrationIds'] = None

        # set to None if attach_nested_product_unit_ids (nullable) is None
        # and model_fields_set contains the field
        if self.attach_nested_product_unit_ids is None and "attach_nested_product_unit_ids" in self.model_fields_set:
            _dict['attachNestedProductUnitIds'] = None

        # set to None if attach_repository_name_substrings (nullable) is None
        # and model_fields_set contains the field
        if self.attach_repository_name_substrings is None and "attach_repository_name_substrings" in self.model_fields_set:
            _dict['attachRepositoryNameSubstrings'] = None

        # set to None if attach_repository_directories (nullable) is None
        # and model_fields_set contains the field
        if self.attach_repository_directories is None and "attach_repository_directories" in self.model_fields_set:
            _dict['attachRepositoryDirectories'] = None

        # set to None if detach_repository_ids (nullable) is None
        # and model_fields_set contains the field
        if self.detach_repository_ids is None and "detach_repository_ids" in self.model_fields_set:
            _dict['detachRepositoryIds'] = None

        # set to None if detach_repository_group_ids (nullable) is None
        # and model_fields_set contains the field
        if self.detach_repository_group_ids is None and "detach_repository_group_ids" in self.model_fields_set:
            _dict['detachRepositoryGroupIds'] = None

        # set to None if detach_integration_ids (nullable) is None
        # and model_fields_set contains the field
        if self.detach_integration_ids is None and "detach_integration_ids" in self.model_fields_set:
            _dict['detachIntegrationIds'] = None

        # set to None if detach_nested_product_unit_ids (nullable) is None
        # and model_fields_set contains the field
        if self.detach_nested_product_unit_ids is None and "detach_nested_product_unit_ids" in self.model_fields_set:
            _dict['detachNestedProductUnitIds'] = None

        # set to None if detach_repository_name_substrings (nullable) is None
        # and model_fields_set contains the field
        if self.detach_repository_name_substrings is None and "detach_repository_name_substrings" in self.model_fields_set:
            _dict['detachRepositoryNameSubstrings'] = None

        # set to None if detach_repository_directories (nullable) is None
        # and model_fields_set contains the field
        if self.detach_repository_directories is None and "detach_repository_directories" in self.model_fields_set:
            _dict['detachRepositoryDirectories'] = None

        # set to None if patch_security_champion_id (nullable) is None
        # and model_fields_set contains the field
        if self.patch_security_champion_id is None and "patch_security_champion_id" in self.model_fields_set:
            _dict['patchSecurityChampionId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PatchProductUnitDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "workspaceId": obj.get("workspaceId"),
            "type": obj.get("type"),
            "environment": obj.get("environment"),
            "businessImpact": obj.get("businessImpact"),
            "attachRepositoryIds": obj.get("attachRepositoryIds"),
            "attachRepositoryGroupIds": obj.get("attachRepositoryGroupIds"),
            "attachIntegrationIds": obj.get("attachIntegrationIds"),
            "attachNestedProductUnitIds": obj.get("attachNestedProductUnitIds"),
            "attachRepositoryNameSubstrings": obj.get("attachRepositoryNameSubstrings"),
            "attachRepositoryDirectories": [RepositoryDirectory.from_dict(_item) for _item in obj["attachRepositoryDirectories"]] if obj.get("attachRepositoryDirectories") is not None else None,
            "detachRepositoryIds": obj.get("detachRepositoryIds"),
            "detachRepositoryGroupIds": obj.get("detachRepositoryGroupIds"),
            "detachIntegrationIds": obj.get("detachIntegrationIds"),
            "detachNestedProductUnitIds": obj.get("detachNestedProductUnitIds"),
            "detachRepositoryNameSubstrings": obj.get("detachRepositoryNameSubstrings"),
            "detachRepositoryDirectories": [RepositoryDirectory.from_dict(_item) for _item in obj["detachRepositoryDirectories"]] if obj.get("detachRepositoryDirectories") is not None else None,
            "patchSecurityChampionId": PatchSecurityChampionIdDto.from_dict(obj["patchSecurityChampionId"]) if obj.get("patchSecurityChampionId") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.product_units_api import ProductUnitsApi


class TestProductUnitsApi(unittest.TestCase):
    """ProductUnitsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProductUnitsApi()

    def tearDown(self) -> None:
        pass

    def test_api_v10_products_get(self) -> None:
        """Test case for api_v10_products_get

        Get all Product Units
        """
        pass

    def test_api_v10_products_id_assets_get(self) -> None:
        """Test case for api_v10_products_id_assets_get

        Get Product Unit Assets
        """
        pass

    def test_api_v10_products_id_custom_fields_by_name_patch(self) -> None:
        """Test case for api_v10_products_id_custom_fields_by_name_patch

        Update Product Unit Custom Fields By Custom Field Name
        """
        pass

    def test_api_v10_products_id_custom_fields_patch(self) -> None:
        """Test case for api_v10_products_id_custom_fields_patch

        Update Product Unit Custom Fields by ID
        """
        pass

    def test_api_v10_products_id_delete(self) -> None:
        """Test case for api_v10_products_id_delete

        Delete Product Unit
        """
        pass

    def test_api_v10_products_id_get(self) -> None:
        """Test case for api_v10_products_id_get

        Get Product Unit by id
        """
        pass

    def test_api_v10_products_id_patch(self) -> None:
        """Test case for api_v10_products_id_patch

        Update Product Unit
        """
        pass

    def test_api_v10_products_issuescount_get(self) -> None:
        """Test case for api_v10_products_issuescount_get

        Get product units issue count by severity
        """
        pass

    def test_api_v10_products_post(self) -> None:
        """Test case for api_v10_products_post

        Create new Product Unit
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.policy_dto import PolicyDto

class TestPolicyDto(unittest.TestCase):
    """PolicyDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PolicyDto:
        """Test PolicyDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PolicyDto`
        """
        model = PolicyDto()
        if include_optional:
            return PolicyDto(
                id = '',
                policy_name = '',
                issue_type = 'Misconfiguration',
                severity = 'Low',
                original_severity = 'Low',
                category = 'Unknown',
                title = '',
                description = '',
                compliances = [
                    ''
                    ],
                is_disabled = True,
                is_user_created = True,
                is_locked = True,
                target_origin_type = 'Collaborator',
                target_scm_types = [
                    'GitHubEnterpriseServer'
                    ],
                open_issues_count = 56,
                definition_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                source = '',
                remediation = ''
            )
        else:
            return PolicyDto(
        )
        """

    def testPolicyDto(self):
        """Test PolicyDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.discovered_sdlc_asset_dto import DiscoveredSdlcAssetDto

class TestDiscoveredSdlcAssetDto(unittest.TestCase):
    """DiscoveredSdlcAssetDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DiscoveredSdlcAssetDto:
        """Test DiscoveredSdlcAssetDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DiscoveredSdlcAssetDto`
        """
        model = DiscoveredSdlcAssetDto()
        if include_optional:
            return DiscoveredSdlcAssetDto(
                sdlc_asset = legit_api_client.models.sdlc_asset_dto.SdlcAssetDto(
                    id = '', 
                    sdlc_asset_type = null, 
                    sdlc_asset_meta_type_display_text = '', 
                    is_integrated = True, 
                    setup_success_status_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    integration_id = '', 
                    url = '', 
                    urls = [
                        ''
                        ], 
                    owner = '', ),
                connections = [
                    legit_api_client.models.asset_connection_dto.AssetConnectionDto(
                        evidence_type = null, 
                        first_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        detailed_sdlc_asset = null, )
                    ]
            )
        else:
            return DiscoveredSdlcAssetDto(
        )
        """

    def testDiscoveredSdlcAssetDto(self):
        """Test DiscoveredSdlcAssetDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.models.repository_dto import RepositoryDto

class TestRepositoryDto(unittest.TestCase):
    """RepositoryDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RepositoryDto:
        """Test RepositoryDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RepositoryDto`
        """
        model = RepositoryDto()
        if include_optional:
            return RepositoryDto(
                id = '',
                name = '',
                url = '',
                visibility = 'Public',
                is_active = True,
                is_archived = True,
                owner = legit_api_client.models.collaborator_dto.CollaboratorDto(
                    id = '', 
                    username = '', 
                    name = '', 
                    display_name = '', 
                    is_admin = True, 
                    email = '', 
                    last_active_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    browse_url = '', ),
                tags = [
                    legit_api_client.models.tag_dto.TagDto(
                        id = '', 
                        name = '', 
                        source = '', )
                    ],
                product_units = [
                    legit_api_client.models.product_unit_name_dto.ProductUnitNameDto(
                        id = '', 
                        name = '', )
                    ],
                issues_count = 56,
                lines_count = 56,
                score = 1.337,
                score_out_of100 = 1.337,
                group = legit_api_client.models.repository_group_dto.RepositoryGroupDto(
                    id = '', 
                    name = '', 
                    integration_id = '', )
            )
        else:
            return RepositoryDto(
        )
        """

    def testRepositoryDto(self):
        """Test RepositoryDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr
from typing import Any, List, Optional
from typing_extensions import Annotated
from legit_api_client.models.collaborator_dto import CollaboratorDto
from legit_api_client.models.collaborator_repository_permission import CollaboratorRepositoryPermission
from legit_api_client.models.repository_visibility import RepositoryVisibility

from legit_api_client.api_client import ApiClient, RequestSerialized
from legit_api_client.api_response import ApiResponse
from legit_api_client.rest import RESTResponseType


class CollaboratorsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_v10_collaborators_get(
        self,
        sort_column: Optional[StrictStr] = None,
        sort_direction: Optional[Any] = None,
        integration_ids: Optional[List[StrictStr]] = None,
        is_admin: Optional[StrictBool] = None,
        is_external_to_all: Optional[StrictBool] = None,
        is_ai_assistant_user: Optional[StrictBool] = None,
        is_owner: Optional[StrictBool] = None,
        page_number: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]] = None,
        page_size: Optional[Annotated[int, Field(le=100, strict=True, ge=1)]] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[CollaboratorDto]:
        """Get all collaborators


        :param sort_column:
        :type sort_column: str
        :param sort_direction:
        :type sort_direction: ListSortDirection
        :param integration_ids:
        :type integration_ids: List[str]
        :param is_admin:
        :type is_admin: bool
        :param is_external_to_all:
        :type is_external_to_all: bool
        :param is_ai_assistant_user:
        :type is_ai_assistant_user: bool
        :param is_owner:
        :type is_owner: bool
        :param page_number:
        :type page_number: int
        :param page_size:
        :type page_size: int
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_collaborators_get_serialize(
            sort_column=sort_column,
            sort_direction=sort_direction,
            integration_ids=integration_ids,
            is_admin=is_admin,
            is_external_to_all=is_external_to_all,
            is_ai_assistant_user=is_ai_assistant_user,
            is_owner=is_owner,
            page_number=page_number,
            page_size=page_size,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[CollaboratorDto]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v10_collaborators_get_with_http_info(
        self,
        sort_column: Optional[StrictStr] = None,
        sort_direction: Optional[Any] = None,
        integration_ids: Optional[List[StrictStr]] = None,
        is_admin: Optional[StrictBool] = None,
        is_external_to_all: Optional[StrictBool] = None,
        is_ai_assistant_user: Optional[StrictBool] = None,
        is_owner: Optional[StrictBool] = None,
        page_number: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]] = None,
        page_size: Optional[Annotated[int, Field(le=100, strict=True, ge=1)]] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[CollaboratorDto]]:
        """Get all collaborators


        :param sort_column:
        :type sort_column: str
        :param sort_direction:
        :type sort_direction: ListSortDirection
        :param integration_ids:
        :type integration_ids: List[str]
        :param is_admin:
        :type is_admin: bool
        :param is_external_to_all:
        :type is_external_to_all: bool
        :param is_ai_assistant_user:
        :type is_ai_assistant_user: bool
        :param is_owner:
        :type is_owner: bool
        :param page_number:
        :type page_number: int
        :param page_size:
        :type page_size: int
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_collaborators_get_serialize(
            sort_column=sort_column,
            sort_direction=sort_direction,
            integration_ids=integration_ids,
            is_admin=is_admin,
            is_external_to_all=is_external_to_all,
            is_ai_assistant_user=is_ai_assistant_user,
            is_owner=is_owner,
            page_number=page_number,
            page_size=page_size,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[CollaboratorDto]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v10_collaborators_get_without_preload_content(
        self,
        sort_column: Optional[StrictStr] = None,
        sort_direction: Optional[Any] = None,
        integration_ids: Optional[List[StrictStr]] = None,
        is_admin: Optional[StrictBool] = None,
        is_external_to_all: Optional[StrictBool] = None,
        is_ai_assistant_user: Optional[StrictBool] = None,
        is_owner: Optional[StrictBool] = None,
        page_number: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]] = None,
        page_size: Optional[Annotated[int, Field(le=100, strict=True, ge=1)]] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all collaborators


        :param sort_column:
        :type sort_column: str
        :param sort_direction:
        :type sort_direction: ListSortDirection
        :param integration_ids:
        :type integration_ids: List[str]
        :param is_admin:
        :type is_admin: bool
        :param is_external_to_all:
        :type is_external_to_all: bool
        :param is_ai_assistant_user:
        :type is_ai_assistant_user: bool
        :param is_owner:
        :type is_owner: bool
        :param page_number:
        :type page_number: int
        :param page_size:
        :type page_size: int
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_collaborators_get_serialize(
            sort_column=sort_column,
            sort_direction=sort_direction,
            integration_ids=integration_ids,
            is_admin=is_admin,
            is_external_to_all=is_external_to_all,
            is_ai_assistant_user=is_ai_assistant_user,
            is_owner=is_owner,
            page_number=page_number,
            page_size=page_size,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[CollaboratorDto]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v10_collaborators_get_serialize(
        self,
        sort_column,
        sort_direction,
        integration_ids,
        is_admin,
        is_external_to_all,
        is_ai_assistant_user,
        is_owner,
        page_number,
        page_size,
        search,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'integrationIds': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if sort_column is not None:
            
            _query_params.append(('sortColumn', sort_column))
            
        if sort_direction is not None:
            
            _query_params.append(('sortDirection', sort_direction.value))
            
        if integration_ids is not None:
            
            _query_params.append(('integrationIds', integration_ids))
            
        if is_admin is not None:
            
            _query_params.append(('isAdmin', is_admin))
            
        if is_external_to_all is not None:
            
            _query_params.append(('isExternalToAll', is_external_to_all))
            
        if is_ai_assistant_user is not None:
            
            _query_params.append(('isAiAssistantUser', is_ai_assistant_user))
            
        if is_owner is not None:
            
            _query_params.append(('isOwner', is_owner))
            
        if page_number is not None:
            
            _query_params.append(('pageNumber', page_number))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if search is not None:
            
            _query_params.append(('search', search))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'text/plain', 
                    'application/json', 
                    'text/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1.0/collaborators',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v10_collaborators_id_get(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CollaboratorDto:
        """Get collaborator by id


        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_collaborators_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CollaboratorDto",
            '404': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v10_collaborators_id_get_with_http_info(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CollaboratorDto]:
        """Get collaborator by id


        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_collaborators_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CollaboratorDto",
            '404': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v10_collaborators_id_get_without_preload_content(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get collaborator by id


        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_collaborators_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CollaboratorDto",
            '404': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v10_collaborators_id_get_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'text/plain', 
                    'application/json', 
                    'text/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1.0/collaborators/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v10_collaborators_id_permissions_get(
        self,
        id: StrictStr,
        sort_column: Optional[StrictStr] = None,
        sort_direction: Optional[Any] = None,
        is_active: Optional[StrictBool] = None,
        is_archived: Optional[StrictBool] = None,
        repository_visibilities: Optional[List[RepositoryVisibility]] = None,
        product_unit_ids: Optional[List[StrictStr]] = None,
        any_product_units: Optional[StrictBool] = None,
        tag_ids: Optional[List[StrictStr]] = None,
        integration_ids: Optional[List[StrictStr]] = None,
        owner_ids: Optional[List[StrictStr]] = None,
        workspace_ids: Optional[List[StrictStr]] = None,
        repository_groups_ids: Optional[List[StrictStr]] = None,
        page_number: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]] = None,
        page_size: Optional[Annotated[int, Field(le=100, strict=True, ge=1)]] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[CollaboratorRepositoryPermission]:
        """Get collaborator permissions


        :param id: (required)
        :type id: str
        :param sort_column:
        :type sort_column: str
        :param sort_direction:
        :type sort_direction: ListSortDirection
        :param is_active:
        :type is_active: bool
        :param is_archived:
        :type is_archived: bool
        :param repository_visibilities:
        :type repository_visibilities: List[RepositoryVisibility]
        :param product_unit_ids:
        :type product_unit_ids: List[str]
        :param any_product_units:
        :type any_product_units: bool
        :param tag_ids:
        :type tag_ids: List[str]
        :param integration_ids:
        :type integration_ids: List[str]
        :param owner_ids:
        :type owner_ids: List[str]
        :param workspace_ids:
        :type workspace_ids: List[str]
        :param repository_groups_ids:
        :type repository_groups_ids: List[str]
        :param page_number:
        :type page_number: int
        :param page_size:
        :type page_size: int
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_collaborators_id_permissions_get_serialize(
            id=id,
            sort_column=sort_column,
            sort_direction=sort_direction,
            is_active=is_active,
            is_archived=is_archived,
            repository_visibilities=repository_visibilities,
            product_unit_ids=product_unit_ids,
            any_product_units=any_product_units,
            tag_ids=tag_ids,
            integration_ids=integration_ids,
            owner_ids=owner_ids,
            workspace_ids=workspace_ids,
            repository_groups_ids=repository_groups_ids,
            page_number=page_number,
            page_size=page_size,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[CollaboratorRepositoryPermission]",
            '404': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v10_collaborators_id_permissions_get_with_http_info(
        self,
        id: StrictStr,
        sort_column: Optional[StrictStr] = None,
        sort_direction: Optional[Any] = None,
        is_active: Optional[StrictBool] = None,
        is_archived: Optional[StrictBool] = None,
        repository_visibilities: Optional[List[RepositoryVisibility]] = None,
        product_unit_ids: Optional[List[StrictStr]] = None,
        any_product_units: Optional[StrictBool] = None,
        tag_ids: Optional[List[StrictStr]] = None,
        integration_ids: Optional[List[StrictStr]] = None,
        owner_ids: Optional[List[StrictStr]] = None,
        workspace_ids: Optional[List[StrictStr]] = None,
        repository_groups_ids: Optional[List[StrictStr]] = None,
        page_number: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]] = None,
        page_size: Optional[Annotated[int, Field(le=100, strict=True, ge=1)]] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[CollaboratorRepositoryPermission]]:
        """Get collaborator permissions


        :param id: (required)
        :type id: str
        :param sort_column:
        :type sort_column: str
        :param sort_direction:
        :type sort_direction: ListSortDirection
        :param is_active:
        :type is_active: bool
        :param is_archived:
        :type is_archived: bool
        :param repository_visibilities:
        :type repository_visibilities: List[RepositoryVisibility]
        :param product_unit_ids:
        :type product_unit_ids: List[str]
        :param any_product_units:
        :type any_product_units: bool
        :param tag_ids:
        :type tag_ids: List[str]
        :param integration_ids:
        :type integration_ids: List[str]
        :param owner_ids:
        :type owner_ids: List[str]
        :param workspace_ids:
        :type workspace_ids: List[str]
        :param repository_groups_ids:
        :type repository_groups_ids: List[str]
        :param page_number:
        :type page_number: int
        :param page_size:
        :type page_size: int
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_collaborators_id_permissions_get_serialize(
            id=id,
            sort_column=sort_column,
            sort_direction=sort_direction,
            is_active=is_active,
            is_archived=is_archived,
            repository_visibilities=repository_visibilities,
            product_unit_ids=product_unit_ids,
            any_product_units=any_product_units,
            tag_ids=tag_ids,
            integration_ids=integration_ids,
            owner_ids=owner_ids,
            workspace_ids=workspace_ids,
            repository_groups_ids=repository_groups_ids,
            page_number=page_number,
            page_size=page_size,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[CollaboratorRepositoryPermission]",
            '404': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v10_collaborators_id_permissions_get_without_preload_content(
        self,
        id: StrictStr,
        sort_column: Optional[StrictStr] = None,
        sort_direction: Optional[Any] = None,
        is_active: Optional[StrictBool] = None,
        is_archived: Optional[StrictBool] = None,
        repository_visibilities: Optional[List[RepositoryVisibility]] = None,
        product_unit_ids: Optional[List[StrictStr]] = None,
        any_product_units: Optional[StrictBool] = None,
        tag_ids: Optional[List[StrictStr]] = None,
        integration_ids: Optional[List[StrictStr]] = None,
        owner_ids: Optional[List[StrictStr]] = None,
        workspace_ids: Optional[List[StrictStr]] = None,
        repository_groups_ids: Optional[List[StrictStr]] = None,
        page_number: Optional[Annotated[int, Field(le=2147483647, strict=True, ge=1)]] = None,
        page_size: Optional[Annotated[int, Field(le=100, strict=True, ge=1)]] = None,
        search: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get collaborator permissions


        :param id: (required)
        :type id: str
        :param sort_column:
        :type sort_column: str
        :param sort_direction:
        :type sort_direction: ListSortDirection
        :param is_active:
        :type is_active: bool
        :param is_archived:
        :type is_archived: bool
        :param repository_visibilities:
        :type repository_visibilities: List[RepositoryVisibility]
        :param product_unit_ids:
        :type product_unit_ids: List[str]
        :param any_product_units:
        :type any_product_units: bool
        :param tag_ids:
        :type tag_ids: List[str]
        :param integration_ids:
        :type integration_ids: List[str]
        :param owner_ids:
        :type owner_ids: List[str]
        :param workspace_ids:
        :type workspace_ids: List[str]
        :param repository_groups_ids:
        :type repository_groups_ids: List[str]
        :param page_number:
        :type page_number: int
        :param page_size:
        :type page_size: int
        :param search:
        :type search: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v10_collaborators_id_permissions_get_serialize(
            id=id,
            sort_column=sort_column,
            sort_direction=sort_direction,
            is_active=is_active,
            is_archived=is_archived,
            repository_visibilities=repository_visibilities,
            product_unit_ids=product_unit_ids,
            any_product_units=any_product_units,
            tag_ids=tag_ids,
            integration_ids=integration_ids,
            owner_ids=owner_ids,
            workspace_ids=workspace_ids,
            repository_groups_ids=repository_groups_ids,
            page_number=page_number,
            page_size=page_size,
            search=search,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[CollaboratorRepositoryPermission]",
            '404': "ProblemDetails",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v10_collaborators_id_permissions_get_serialize(
        self,
        id,
        sort_column,
        sort_direction,
        is_active,
        is_archived,
        repository_visibilities,
        product_unit_ids,
        any_product_units,
        tag_ids,
        integration_ids,
        owner_ids,
        workspace_ids,
        repository_groups_ids,
        page_number,
        page_size,
        search,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'repositoryVisibilities': 'multi',
            'productUnitIds': 'multi',
            'tagIds': 'multi',
            'integrationIds': 'multi',
            'ownerIds': 'multi',
            'workspaceIds': 'multi',
            'repositoryGroupsIds': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        if sort_column is not None:
            
            _query_params.append(('sortColumn', sort_column))
            
        if sort_direction is not None:
            
            _query_params.append(('sortDirection', sort_direction.value))
            
        if is_active is not None:
            
            _query_params.append(('isActive', is_active))
            
        if is_archived is not None:
            
            _query_params.append(('isArchived', is_archived))
            
        if repository_visibilities is not None:
            
            _query_params.append(('repositoryVisibilities', repository_visibilities))
            
        if product_unit_ids is not None:
            
            _query_params.append(('productUnitIds', product_unit_ids))
            
        if any_product_units is not None:
            
            _query_params.append(('anyProductUnits', any_product_units))
            
        if tag_ids is not None:
            
            _query_params.append(('tagIds', tag_ids))
            
        if integration_ids is not None:
            
            _query_params.append(('integrationIds', integration_ids))
            
        if owner_ids is not None:
            
            _query_params.append(('ownerIds', owner_ids))
            
        if workspace_ids is not None:
            
            _query_params.append(('workspaceIds', workspace_ids))
            
        if repository_groups_ids is not None:
            
            _query_params.append(('repositoryGroupsIds', repository_groups_ids))
            
        if page_number is not None:
            
            _query_params.append(('pageNumber', page_number))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if search is not None:
            
            _query_params.append(('search', search))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'text/plain', 
                    'application/json', 
                    'text/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1.0/collaborators/{id}/permissions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from legit_api_client.api.repositories_api import RepositoriesApi


class TestRepositoriesApi(unittest.TestCase):
    """RepositoriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RepositoriesApi()

    def tearDown(self) -> None:
        pass

    def test_api_v10_repositories_get(self) -> None:
        """Test case for api_v10_repositories_get

        Get all repositories
        """
        pass

    def test_api_v10_repositories_id_controls_get(self) -> None:
        """Test case for api_v10_repositories_id_controls_get

        Get repository controls
        """
        pass

    def test_api_v10_repositories_id_get(self) -> None:
        """Test case for api_v10_repositories_id_get

        Get repository by id
        """
        pass

    def test_api_v10_repositories_id_owner_delete(self) -> None:
        """Test case for api_v10_repositories_id_owner_delete

        Delete owner from repository
        """
        pass

    def test_api_v10_repositories_id_owner_owner_id_put(self) -> None:
        """Test case for api_v10_repositories_id_owner_owner_id_put

        Set owner to repository
        """
        pass

    def test_api_v10_repositories_id_score_get(self) -> None:
        """Test case for api_v10_repositories_id_score_get

        Get repository score
        """
        pass

    def test_api_v10_repositories_repo_id_tags_tag_id_delete(self) -> None:
        """Test case for api_v10_repositories_repo_id_tags_tag_id_delete

        Remove tag from repository
        """
        pass

    def test_api_v10_repositories_repo_id_tags_tag_id_post(self) -> None:
        """Test case for api_v10_repositories_repo_id_tags_tag_id_post

        Add tag to repository
        """
        pass

    def test_api_v10_repositories_score_get(self) -> None:
        """Test case for api_v10_repositories_score_get

        Get repositories score
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Inventory

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from legit_api_client.models.collaborator_dto import CollaboratorDto
from legit_api_client.models.product_unit_name_dto import ProductUnitNameDto
from legit_api_client.models.repository_group_dto import RepositoryGroupDto
from legit_api_client.models.repository_visibility import RepositoryVisibility
from legit_api_client.models.tag_dto import TagDto
from typing import Optional, Set
from typing_extensions import Self

class RepositoryDto(BaseModel):
    """
    RepositoryDto
    """ # noqa: E501
    id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    url: Optional[StrictStr] = None
    visibility: Optional[RepositoryVisibility] = None
    is_active: Optional[StrictBool] = Field(default=None, alias="isActive")
    is_archived: Optional[StrictBool] = Field(default=None, alias="isArchived")
    owner: Optional[CollaboratorDto] = None
    tags: Optional[List[TagDto]] = None
    product_units: Optional[List[ProductUnitNameDto]] = Field(default=None, alias="productUnits")
    issues_count: Optional[StrictInt] = Field(default=None, alias="issuesCount")
    lines_count: Optional[StrictInt] = Field(default=None, alias="linesCount")
    score: Optional[Union[StrictFloat, StrictInt]] = None
    score_out_of100: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="scoreOutOf100")
    group: Optional[RepositoryGroupDto] = None
    __properties: ClassVar[List[str]] = ["id", "name", "url", "visibility", "isActive", "isArchived", "owner", "tags", "productUnits", "issuesCount", "linesCount", "score", "scoreOutOf100", "group"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RepositoryDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "score_out_of100",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of owner
        if self.owner:
            _dict['owner'] = self.owner.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in product_units (list)
        _items = []
        if self.product_units:
            for _item_product_units in self.product_units:
                if _item_product_units:
                    _items.append(_item_product_units.to_dict())
            _dict['productUnits'] = _items
        # override the default output from pydantic by calling `to_dict()` of group
        if self.group:
            _dict['group'] = self.group.to_dict()
        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if url (nullable) is None
        # and model_fields_set contains the field
        if self.url is None and "url" in self.model_fields_set:
            _dict['url'] = None

        # set to None if visibility (nullable) is None
        # and model_fields_set contains the field
        if self.visibility is None and "visibility" in self.model_fields_set:
            _dict['visibility'] = None

        # set to None if is_active (nullable) is None
        # and model_fields_set contains the field
        if self.is_active is None and "is_active" in self.model_fields_set:
            _dict['isActive'] = None

        # set to None if owner (nullable) is None
        # and model_fields_set contains the field
        if self.owner is None and "owner" in self.model_fields_set:
            _dict['owner'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        # set to None if product_units (nullable) is None
        # and model_fields_set contains the field
        if self.product_units is None and "product_units" in self.model_fields_set:
            _dict['productUnits'] = None

        # set to None if lines_count (nullable) is None
        # and model_fields_set contains the field
        if self.lines_count is None and "lines_count" in self.model_fields_set:
            _dict['linesCount'] = None

        # set to None if score (nullable) is None
        # and model_fields_set contains the field
        if self.score is None and "score" in self.model_fields_set:
            _dict['score'] = None

        # set to None if score_out_of100 (nullable) is None
        # and model_fields_set contains the field
        if self.score_out_of100 is None and "score_out_of100" in self.model_fields_set:
            _dict['scoreOutOf100'] = None

        # set to None if group (nullable) is None
        # and model_fields_set contains the field
        if self.group is None and "group" in self.model_fields_set:
            _dict['group'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RepositoryDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "url": obj.get("url"),
            "visibility": obj.get("visibility"),
            "isActive": obj.get("isActive"),
            "isArchived": obj.get("isArchived"),
            "owner": CollaboratorDto.from_dict(obj["owner"]) if obj.get("owner") is not None else None,
            "tags": [TagDto.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "productUnits": [ProductUnitNameDto.from_dict(_item) for _item in obj["productUnits"]] if obj.get("productUnits") is not None else None,
            "issuesCount": obj.get("issuesCount"),
            "linesCount": obj.get("linesCount"),
            "score": obj.get("score"),
            "scoreOutOf100": obj.get("scoreOutOf100"),
            "group": RepositoryGroupDto.from_dict(obj["group"]) if obj.get("group") is not None else None
        })
        return _obj


